# Pilote

###### Something interesting coming up.

Project codebase: <https://github.com/omprakash1989/pilote>

Project Documentation: <http://pilote.readthedocs.io/en/latest>

***

#### Python Library Requirements
All the python library requirements are specified in requirements.txt file.

To install the required libraries:  
`pip install -r requirements.txt`
